
.. _network_resources:

************************
Resources and next steps
************************

.. contents::
   :local:

Documents
=========

Read more about Ansible for Network Automation:

- Network Automation on the `Ansible website <https://www.ansible.com/overview/networking>`_
- Ansible Network `Blog posts <https://www.ansible.com/blog/topic/networks>`_

Events (on video and in person)
===============================

All sessions at Ansible events are recorded and include many Network-related topics (use Filter by Category to view only Network topics). You can also join us for future events in your area. See:

- `Recorded AnsibleFests <https://www.ansible.com/resources/videos/ansiblefest>`_
- `Recorded AnsibleAutomates <https://www.ansible.com/resources/webinars-training>`_
- `Upcoming Ansible Events <https://www.ansible.com/community/events>`_ page.

GitHub repos
============

Ansible hosts module code, examples, demonstrations, and other content on GitHub. Anyone with a GitHub account is able to create Pull Requests (PRs) or issues on these repos:

- `Network-Automation <https://github.com/network-automation>`_ is an open community for all things network automation. Have an idea, some playbooks, or roles to share? Email ansible-network@redhat.com and we will add you as a contributor to the repository.

- `Ansible collections <https://github.com/ansible-collections>`_ is the main repository for Ansible-maintained and community collections, including collections for network devices.



IRC and Slack
=============

Join us on:

* IRC Channel - ``#ansible-network`` on `irc.libera.chat <https://libera.chat/>`_

* Slack - `<https://ansiblenetwork.slack.com>`_
